@@ -1,12 +1,19 @@
-#' Method that runs the daisy algorithm using the euclidean metric to make an external or internal validation of the cluster.
+#' Method that runs the daisy algorithm using the euclidean metric to make an
+#' external or internal validation of the cluster.
 #'
-#' @param dt matrix or data frame with the set of values to be applied to the algorithm.
-#' @param clusters is an integer that indexes the number of clusters we want to create.
-#' @param columnClass is an integer with the number of columns, for example if a dataset has five column,
-#' we can select column four to calculate alidation.
-#' @param metric is a characters vector with the metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' @param dt matrix or data frame with the set of values to be applied to the
+#' algorithm.
+#' @param clusters is an integer that indexes the number of clusters we want to
+#' create.
+#' @param columnClass is an integer with the number of columns, for example if a
+#' dataset has five column, we can select column four to calculate validation.
+#' @param metric is a characters vector with the metrics avalaible in the
+#' package. The metrics implemented are: entropy, variation_information,
+#' precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,
+#' silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the grouping.
+#' @return returns a list with both the internal and external evaluation of the
+#' grouping.
 #'
 #' @keywords internal
 #'
@@ -31,13 +38,15 @@ daisy_euclidean_method = function(dt, clusters, columnClass, metric) {
   })
 
   if (!is.null(daisy_euclidean)) {
-    daisy_euclidean_clust = hclust(dist(daisy_euclidean), method = CONST_CENTROID)
+    daisy_euclidean_clust = hclust(dist(daisy_euclidean),
+                                   method = CONST_CENTROID)
 
     if (!is.null(daisy_euclidean_clust)) {
       ev_daisy_euclidean <-
         tryCatch({
           external_validation(c(dt[, columnClass]),
-                              cutree(daisy_euclidean_clust, k = clusters),metric)
+                              cutree(daisy_euclidean_clust, k = clusters)
+                              ,metric)
 
         },
 
@@ -84,15 +93,22 @@ daisy_euclidean_method = function(dt, clusters, columnClass, metric) {
 
 }
 
-#' Method that runs the daisy algorithm using the manhattan metric to make an external or internal validation of the cluster.
+#' Method that runs the daisy algorithm using the manhattan metric to make an
+#' external or internal validation of the cluster.
 #'
-#' @param dt matrix or data frame with the set of values to be applied to the algorithm.
-#' @param clusters is an integer that indexes the number of clusters we want to create.
-#' @param columnClass is an integer with the number of columns, for example if a dataset has five column,
-#' we can select column four to calculate alidation.
-#' @param metric is a characters vector with the metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' @param dt matrix or data frame with the set of values to be applied to the
+#' algorithm.
+#' @param clusters is an integer that indexes the number of clusters we want to
+#' create.
+#' @param columnClass is an integer with the number of columns, for example if a
+#' dataset has five column, we can select column four to calculate validation.
+#' @param metric is a characters vector with the metrics avalaible in the
+#' package. The metrics implemented are: entropy, variation_information,
+#' precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,
+#' silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the grouping.
+#' @return returns a list with both the internal and external evaluation of the
+#' grouping.
 #'
 #' @keywords internal
 #'
@@ -131,7 +147,8 @@ daisy_manhattan_method = function(dt, clusters, columnClass, metric) {
       ev_daisy_manhattan <-
         tryCatch({
           external_validation(c(dt[, columnClass]),
-                              cutree(daisy_manhattan_clust, k = clusters),metric)
+                              cutree(daisy_manhattan_clust, k = clusters)
+                              ,metric)
 
         },
 
@@ -180,15 +197,22 @@ daisy_manhattan_method = function(dt, clusters, columnClass, metric) {
 
 }
 
-#' Method that runs the daisy algorithm using the gower metric to make an external or internal validation of the cluster.
+#' Method that runs the daisy algorithm using the gower metric to make an
+#' external or internal validation of the cluster.
 #'
-#' @param dt matrix or data frame with the set of values to be applied to the algorithm.
-#' @param clusters is an integer that indexes the number of clusters we want to create.
-#' @param columnClass is an integer with the number of columns, for example if a dataset has five column,
-#' we can select column four to calculate alidation.
-#' @param metric is a characters vector with the metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' @param dt matrix or data frame with the set of values to be applied to the
+#' algorithm.
+#' @param clusters is an integer that indexes the number of clusters we want to
+#' create.
+#' @param columnClass is an integer with the number of columns, for example if a
+#' dataset has five column, we can select column four to calculate validation.
+#' @param metric is a characters vector with the metrics avalaible in the
+#' package. The metrics implemented are: entropy, variation_information,
+#' precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,
+#' silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the grouping.
+#' @return returns a list with both the internal and external evaluation of the
+#' grouping.
 #'
 #' @keywords internal
 #'
